import * as cloudfront from "aws-cdk-lib/aws-cloudfront";
import * as origins from "aws-cdk-lib/aws-cloudfront-origins";
import * as route53 from "aws-cdk-lib/aws-route53";
import * as s3 from "aws-cdk-lib/aws-s3";
/**
 * S3 origin information
 */
export interface S3OriginInfo {
    readonly id: string;
    readonly bucket: s3.IBucket;
}
/**
 * HTTP origin information
 */
export interface HttpOriginInfo {
    readonly id: string;
    readonly origin: origins.HttpOrigin;
}
export interface S3OriginConfig {
    /**
     * Unique identifier for this S3 origin
     * Used to reference this origin in cache behaviors
     */
    readonly id: string;
    /**
     * Existing S3 bucket to use as origin (required)
     */
    readonly bucket: s3.IBucket;
    /**
     * Origin path for S3 requests (e.g., "/static")
     */
    readonly originPath?: string;
    /**
     * Additional S3 origin properties
     */
    readonly s3OriginProps?: origins.S3OriginProps;
}
export interface HttpOriginConfig {
    /**
     * Unique identifier for this HTTP origin
     * Used to reference this origin in cache behaviors
     */
    readonly id: string;
    /**
     * Domain name of the HTTP origin (required)
     */
    readonly domainName: string;
    /**
     * Origin path for HTTP requests (e.g., "/api/v1")
     */
    readonly originPath?: string;
    /**
     * Protocol policy for the origin
     * @default HTTPS_ONLY
     */
    readonly protocolPolicy?: cloudfront.OriginProtocolPolicy;
    /**
     * HTTP port (for HTTP protocol)
     * @default 80
     */
    readonly httpPort?: number;
    /**
     * HTTPS port (for HTTPS protocol)
     * @default 443
     */
    readonly httpsPort?: number;
    /**
     * Additional HTTP origin properties
     */
    readonly httpOriginProps?: origins.HttpOriginProps;
}
export interface CacheBehaviorConfig {
    /**
     * Path pattern for this behavior (e.g., "/api/*", "*.jpg")
     */
    readonly pathPattern: string;
    /**
     * Origin ID to route this pattern to
     * Must match an ID from s3Origins or httpOrigins
     */
    readonly originId: string;
    /**
     * Viewer protocol policy
     * @default REDIRECT_TO_HTTPS
     */
    readonly viewerProtocolPolicy?: cloudfront.ViewerProtocolPolicy;
    /**
     * Allowed HTTP methods
     * @default ALLOW_GET_HEAD for S3, ALLOW_ALL for HTTP
     */
    readonly allowedMethods?: cloudfront.AllowedMethods;
    /**
     * Methods to cache
     * @default CACHE_GET_HEAD_OPTIONS
     */
    readonly cachedMethods?: cloudfront.CachedMethods;
    /**
     * Enable compression
     * @default true for S3, false for HTTP (to avoid double compression)
     */
    readonly compress?: boolean;
    /**
     * Cache policy ID (use AWS managed policies)
     * @default Appropriate policy based on origin type
     */
    readonly cachePolicyId?: string;
    /**
     * Origin request policy ID
     */
    readonly originRequestPolicyId?: string;
    /**
     * Response headers policy ID
     */
    readonly responseHeadersPolicyId?: string;
}
export interface CloudFrontToOriginsProps {
    /**
     * S3 origins configuration
     * Each origin must have a unique ID
     */
    readonly s3Origins?: S3OriginConfig[];
    /**
     * HTTP origins configuration
     * Each origin must have a unique ID
     */
    readonly httpOrigins?: HttpOriginConfig[];
    /**
     * ID of the origin to use as default behavior
     * Must match an ID from s3Origins or httpOrigins
     * If not specified, will use the first S3 origin, then first HTTP origin
     */
    readonly defaultOriginId?: string;
    /**
     * Cache behaviors for specific path patterns
     *
     * For hybrid distributions, this is automatically configured to:
     * - Route /api/* to first HTTP origin
     * - Route everything else to first S3 origin
     *
     * You can override or add additional behaviors here
     */
    readonly cacheBehaviors?: CacheBehaviorConfig[];
    /**
     * Custom domain name for the CloudFront distribution
     */
    readonly customDomainName?: string;
    /**
     * Route53 hosted zone for the custom domain
     * Required if customDomainName is provided and certificateArn is not
     */
    readonly hostedZone?: route53.IHostedZone;
    /**
     * ARN of existing ACM certificate
     * If not provided and customDomainName is set, a new certificate will be created
     */
    readonly certificateArn?: string;
    /**
     * Enable CloudFront access logging
     * @default true
     */
    readonly enableLogging?: boolean;
    /**
     * Existing S3 bucket for logs
     * If not provided and logging is enabled, a new bucket will be created
     */
    readonly logBucket?: s3.IBucket;
    /**
     * Prefix for log files
     * @default "cloudfront-logs/"
     */
    readonly logPrefix?: string;
    /**
     * Include cookies in access logs
     * @default false
     */
    readonly logIncludeCookies?: boolean;
    /**
     * Custom error page configurations
     *
     * Defaults are applied based on origin configuration:
     * - S3 only: SPA-friendly routing (404/403 → /index.html)
     * - HTTP only: Standard error pages
     * - Hybrid: SPA routing for non-API paths
     */
    readonly errorPages?: cloudfront.ErrorResponse[];
    /**
     * Geographic restriction configuration
     */
    readonly geoRestriction?: cloudfront.GeoRestriction;
    /**
     * Web Application Firewall (WAF) web ACL ID
     */
    readonly webAclId?: string;
}
